<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://#
 * @since      1.0.0
 *
 * @package    Ytautocaptioncrafter
 * @subpackage Ytautocaptioncrafter/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ytautocaptioncrafter
 * @subpackage Ytautocaptioncrafter/admin
 * @author     Ytautocaptioncrafter <ytautocaptioncrafter@ytautocaptioncrafter.com>
 */ 
class Ytautocaptioncrafter_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
        $this->plugin_name = $plugin_name;
		$this->version = $version;
    }
    /**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
        /**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ytautocaptioncrafter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ytautocaptioncrafter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style('toastr', plugin_dir_url( __FILE__ ) .'css/toastr.min.css', array(), $this->version, 'all');
		wp_enqueue_style('plugin-fonts', plugin_dir_url( __FILE__ ) . 'css/fonts.css', array(), $this->version, 'all' );
		wp_enqueue_style($this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/ytautocaptioncrafter-admin.css', array(), $this->version, 'all' );
    }
    /**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
        /**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ytautocaptioncrafter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ytautocaptioncrafter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */ 
		wp_enqueue_script('toastr', plugin_dir_url( __FILE__ ).'js/toastr.min.js', array('jquery'), $this->version, false);
		wp_enqueue_script($this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ytautocaptioncrafter-admin.js', array( 'jquery' ), $this->version, false );
        wp_localize_script($this->plugin_name, 'ytautocaptioncrafter_ajax_path', array(
			'url' => admin_url('admin-ajax.php'),
			) 
	    );  
          
	} 
	/**
	 * Yt Auto Caption Crafter
	 */
    public function ytautocaptioncrafter_admin_menus(){
    	/**
    	 * Dashboard Menu
    	 */
    	add_menu_page( 
    		esc_html__('YT Autocaption Crafter','yt-autocaptioncrafter'),
    		esc_html__('YT Autocaption Crafter','yt-autocaptioncrafter'),
    		'manage_options',
    	 	'ytautocaptioncrafter-setting',
			array($this, 'ytautocaptioncrafter_setting_option'),
			plugins_url('ytauto-captioncrafter/admin/images/menu-icon.png'),
    	 	6
       	  );  
		/**
		 * Yt Auto Caption Crafter Api Option
		 */
	    add_submenu_page('ytautocaptioncrafter-setting', 
			esc_html__('API Settings','yt-autocaptioncrafter'), 
			esc_html__('API Settings','yt-autocaptioncrafter'), 
			'manage_options', 
			'yt-autocaptioncrafter', 
			array($this, 'ytautocaptioncrafter_api_setting_option')
	      ); 
		  
		add_submenu_page('ytautocaptioncrafter-setting', 
			esc_html__('GPT API Settings','yt-autocaptioncrafter'), 
			esc_html__('GPT API Settings','yt-autocaptioncrafter'), 
			'manage_options', 
			'gpt-settings',
			array($this, 'ytautocaptioncrafter_gpt_api_setting')
		); 
		add_submenu_page('ytautocaptioncrafter-setting', 
			esc_html__('RSS Feeds Settings','yt-autocaptioncrafter'), 
			esc_html__('RSS Feeds Settings','yt-autocaptioncrafter'), 
			'manage_options', 
			'rss-feeds-settings',
			array($this, 'ytautocaptioncrafter_rss_feeds_setting')
		); 
		/*add_submenu_page('ytautocaptioncrafter-setting', 
			esc_html__('Facebook Feed','yt-autocaptioncrafter'), 
			esc_html__('Facebook Feed','yt-autocaptioncrafter'), 
			'manage_options', 
			'facebook-feed-settings',
			array($this, 'ytautocaptioncrafter_facebook_feed_settings')
		); */
    }
	/**
	 * Yt Auto Caption Crafter Api Option
	 */
    public function ytautocaptioncrafter_api_setting_option(){
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-admin-api-setting.php';
	}
	/**
	 * Yt Auto Caption Crafter Api Option
	 */
    public function ytautocaptioncrafter_gpt_api_setting(){
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-gpt-admin-setting.php';
	}
	/*public function ytautocaptioncrafter_facebook_feed_settings(){
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'fbfeed/index.php';
	}*/
	
	/**
	 * Yt Auto Caption Crafter Api Option
	 */
    public function ytautocaptioncrafter_rss_feeds_setting(){
		$wpcat = '';
		$args = array(
			'hide_empty'     => 0,
		);
		$wpcat = get_categories($args);	
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-rss-feed-display.php';
	}
	/**
	 * Yt Auto Caption Crafter
	 */ 
	public function ytautocaptioncrafter_setting_option(){
		$youtube_api = get_option('ytc_youtube_api');
		if(empty($youtube_api)):
		   require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-admin-api-setting.php';
        else:
		    $yt_video_id = '';
			if(!empty($_GET['vid'])):
			    $yt_video_id = sanitize_text_field($_GET['vid']); 
                $json = wp_remote_get('https://www.googleapis.com/youtube/v3/videos?id='.$yt_video_id.'&key='.$youtube_api.'&part=snippet');
                $ytdata = json_decode($json['body'],true);
				$curl = curl_init(); 
			    curl_setopt_array($curl, array(
					CURLOPT_URL => 'https://ajaxcontact.node.pixelnx.com/caption/'.$yt_video_id,
					CURLOPT_RETURNTRANSFER => true,
					CURLOPT_ENCODING => '',
					CURLOPT_MAXREDIRS => 10,
					CURLOPT_TIMEOUT => 0,
					CURLOPT_FOLLOWLOCATION => true,
					CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
					CURLOPT_CUSTOMREQUEST => 'POST',
			     ));
			  $response = curl_exec($curl);
			  curl_close($curl);
			  $resdata = json_decode($response,true);
			  $textcontent = '';
			  if(!empty($resdata)):
				foreach($resdata as $data):
					if(isset($data['text'])):
					  $textcontent .= $data['text'];
                    endif;
				endforeach;
			  endif;
                require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-admin-create-post.php';
			  else:
				$lang = esc_html__('en','yt-autocaptioncrafter');
				$keyword_arr = array('motivational','social','yoga','ai','religation','meditation','business','share market','miraculous','war','weapons');
	            shuffle($keyword_arr);
				$search_keyword = esc_html($keyword_arr[0]);
				$feed_url = 'https://www.googleapis.com/youtube/v3/search?relevanceLanguage='.$lang .'&chart=mostPopular&videoEmbeddable=true&videoCaption=closedCaption&part=snippet&type=video&q='.urlencode($search_keyword).'&key='.$youtube_api; 
                $jsondata = wp_remote_get($feed_url);
				$ytdata = json_decode($jsondata['body'],true);
				require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-admin-display.php';
			endif;
		endif;
    }
    /**
	 * Yt Auto Caption Crafter Api Verify And Save
	 */
	public function ytautocaptioncrafter_api_verify_save(){
		$yt_api_key = '';
	    if(!empty($_POST['yt_api_key'])):
		  $yt_api_key = sanitize_text_field($_POST['yt_api_key']); 
	    endif;
		$videoID = esc_html__('GGlanBI_hbw','yt-autocaptioncrafter');
		try {
            $videoID = esc_html__('GGlanBI_hbw','yt-autocaptioncrafter');
			$requestUrl = 'https://www.googleapis.com/youtube/v3/videos?part=id&id='.$videoID .'&key='.$yt_api_key;
			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL, $requestUrl);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1 );
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
			$response = curl_exec( $curl );
			curl_close($curl);
			$json_response = json_decode($response, true);
            if(isset($json_response['error'])){
				echo json_encode(array('status'=>'fail','msg'=>$json_response['error']['message']));
			}else{
                $yt_api_key_save = update_option('ytc_youtube_api',$yt_api_key);
	            if($yt_api_key_save):
					echo json_encode(array('status'=>'success','msg'=> esc_html__('Ytautocaptioncrafter API Saved','yt-autocaptioncrafter')));
				else:
					echo json_encode(array('status'=>'fail','msg'=> esc_html__('Something Went Wrong!','yt-autocaptioncrafter')));
				endif;
            } 
        }catch(Exception $e) {
			echo 'Message: ' .$e->getMessage();
			echo json_encode(array('status'=>'fail','msg'=> $e->getMessage()));
		} 
	    wp_die(); 	
	}
    /** 
	 * Yt Auto Caption Crafter Api Disconnection
	 */
	public function ytautocaptioncrafter_api_disconnection(){
        $key_delete = delete_option('ytc_youtube_api');
		if($key_delete > 0):
		    echo json_encode(array('status'=>'success','message'=>esc_html__('Ytautocaptioncrafter Api Disconnection','yt-autocaptioncrafter')));
		else:
			echo json_encode(array('status'=>'fail','msg'=>esc_html__('Something Went Wrong!','yt-autocaptioncrafter')));
		endif;  
        wp_die();	  
	} 

	/**
	 * Yt Auto Caption Crafter Videos Filter 
	 */ 
	public function ytautocaptioncrafter_videos_filters(){
		$youtube_api = get_option('ytc_youtube_api');
		$lang = '';
		if(isset($_POST['search_languach'])):
			$lang = sanitize_text_field($_POST['search_languach']);
		endif;
		$search_keyword = '';
		if(isset($_POST['search_key_words'])):
			$search_keyword = sanitize_text_field($_POST['search_key_words']);
		endif;
	    $feed_url = 'https://www.googleapis.com/youtube/v3/search?relevanceLanguage='.$lang.'&chart=mostPopular&videoEmbeddable=true&videoCaption=closedCaption&part=snippet&type=video&q='.urlencode($search_keyword) .'&key='.$youtube_api;
		$json = wp_remote_get($feed_url);
        $ytdata = json_decode($json['body'],true);
		if(!empty($ytdata['items'])):
			foreach($ytdata['items'] as $postvideo_list):
			if(!empty($postvideo_list['snippet']['title'])):
				$JSON = wp_remote_get("https://www.googleapis.com/youtube/v3/videos?part=statistics&id=" . $postvideo_list['id']['videoId']. "&key=".$youtube_api);
				$JSON_Data = json_decode($JSON['body'],true);
		?> 
		<div class="ytc-thumb-box">
			<?php if(isset($postvideo_list['snippet']['thumbnails']['default']['url'])): ?>
			<div class="ytc-thumb-video"> 
				<a href="javascript:void(0);" open-modal="videoModal" class="ytc-modal-link">
					<img src="<?php echo esc_url($postvideo_list['snippet']['thumbnails']['default']['url']); ?>" alt="<?php echo esc_attr($postvideo_list['snippet']['title']); ?>"> 
					<span class="ytc-hover-icon" data-videourl="<?php echo esc_url('https://www.youtube.com/embed/'.esc_attr($postvideo_list['id']['videoId'])); ?>"> 
					<svg xmlns="http://www.w3.org/2000/svg" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" x="0" y="0" viewBox="0 0 512 512" xml:space="preserve"><g><path d="m484.102 263.836 4.8-7.836-4.8-7.84c-.805-1.308-20.118-32.48-57.637-63.719-49.903-41.543-108.692-63.504-170.016-63.504-61.308 0-120.242 21.95-170.43 63.473-37.734 31.223-57.265 62.371-58.078 63.684L23.04 256l4.902 7.906c.813 1.313 20.344 32.461 58.079 63.684 50.187 41.523 109.12 63.472 170.43 63.472 61.323 0 120.112-21.96 170.015-63.503 37.52-31.239 56.832-62.41 57.637-63.723zm-77.63 41.324c-44.89 37.094-95.367 55.899-150.023 55.899-54.676 0-105.316-18.817-150.511-55.934C82.563 285.93 66.715 266.492 58.953 256c7.766-10.5 23.613-29.934 46.985-49.129 45.195-37.113 95.832-55.934 150.511-55.934 54.656 0 105.13 18.81 150.024 55.899 23.27 19.226 38.98 38.691 46.636 49.164-7.664 10.477-23.37 29.941-46.636 49.16zm0 0" fill="currentColor" /><path d="M256 165.867c-49.7 0-90.133 40.434-90.133 90.133s40.434 90.133 90.133 90.133 90.133-40.434 90.133-90.133-40.434-90.133-90.133-90.133zm0 150.266c-33.156 0-60.133-26.977-60.133-60.133s26.977-60.133 60.133-60.133 60.133 26.977 60.133 60.133-26.977 60.133-60.133 60.133zM30 30h62.625V0H0v91.5h30zM419.375 0v30H482v61.5h30V0zM30 420.5H0V512h92.625v-30H30zM482 482h-62.625v30H512v-91.5h-30zm0 0" fill="currentColor" /></g></svg>
					</span>
				</a>
		    </div>
		<?php endif; ?>
		<div class="ytc-thumb-content">
			<?php if(!empty($postvideo_list['snippet']['title'])): ?>
			<h4><?php echo esc_html($postvideo_list['snippet']['title']); ?></h4>
			<?php endif; ?>
			<?php if(isset($JSON_Data['items'][0]['statistics']['likeCount'])): ?>
			<ul class="yt-post-info">
				<li>
				<span>
				 <img src="<?php echo esc_url(plugins_url('ytauto-captioncrafter/admin/images/like.svg')); ?>" alt="<?php echo esc_attr__('Likes','yt-autocaptioncrafter'); ?>" />
				</span>
				<?php if(isset($JSON_Data['items'][0]['statistics']['likeCount'])): ?>
				<?php 
				echo ytautocaptioncrafter_format_number($JSON_Data['items'][0]['statistics']['likeCount']); 
				echo esc_html__(' Likes','yt-autocaptioncrafter');  
				?> 
				</li>
				<li>
				<span>
				<img src="<?php echo esc_url(plugins_url( 'ytauto-captioncrafter/admin/images/views.svg')); ?>" alt="<?php echo esc_attr__('Views','yt-autocaptioncrafter'); ?>" />
				</span> 
				<?php endif;
				if(isset($JSON_Data['items'][0]['statistics']['viewCount'])):
				?>
				<?php echo ytautocaptioncrafter_format_number($JSON_Data['items'][0]['statistics']['viewCount']); ?> <?php echo esc_html__('Views','yt-autocaptioncrafter'); ?>
				<?php endif; ?>
				</li>
			</ul>
			<?php 
			endif;
			if(isset($postvideo_list['id']['videoId'])): ?>
			<div class="ytc-thumb-btn">
				<a href="<?php echo admin_url('admin.php?page=ytautocaptioncrafter-setting&vid='.esc_attr($postvideo_list['id']['videoId'])); ?>" class="ytc-btn">
					<?php echo esc_html__('Create Post','yt-autocaptioncrafter'); ?>
				</a>
			</div>
			<?php endif; ?>
		  </div>
	    </div>
	   <?php  
	   endif;
	  endforeach;
	 else:
		if(isset($ytdata['error']['message'])):
			echo "<h1>".wp_kses($ytdata['error']['message'],true)."</h1>";
		else:
			echo "<h1>".esc_html__('Search result is not found!','yt-autocaptioncrafter')."</h1>";
		endif;
	 endif; 
	wp_die();	
	}
    /**
	 * Yt Auto Caption Crafter Videos Text Save in Post
     */
	public function ytautocaptioncrafter_videos_saveinpost(){
        $author_id = get_current_user_id();
		$title = '';
		if(isset($_POST['post_title'])):
			$title = sanitize_text_field($_POST['post_title']);
		endif;
		$video_id = '';
		if(isset($_POST['ytc_video_id'])):
			$video_id = sanitize_text_field($_POST['ytc_video_id']);
		endif;
	    $content = '';
	    if(isset($_POST['mycustomeditor'])):
	     $content = sanitize_text_field($_POST['mycustomeditor']);
	    endif;
		$status = '';
	    if(isset($_POST['post_status'])):
	      $status = sanitize_text_field($_POST['post_status']);
	    endif;
        $date = date('Y-m-d H:i:s', time());
		$include_thumbnail = '';
		if(isset($_POST['include_thumbnail'])):
			$include_thumbnail = sanitize_text_field($_POST['include_thumbnail']);
		endif;
	    $include_video_post = '';
	    if(isset($_POST['include_video_post'])):
	     $include_video_post = sanitize_text_field($_POST['include_video_post']);
	    endif;
		$categories = '';
	    if(isset($_POST['post_categories'])):
	     $categories = sanitize_text_field($_POST['post_categories']);
        endif;
		$tags = '';
		if(isset($_POST['post_tags'])):
	     $tags = sanitize_text_field($_POST['post_tags']);
        endif;
		$thumb_image_url = '';
		if(isset($_POST['thumb_image_url'])):
		  $thumb_image_url = sanitize_text_field($_POST['thumb_image_url']);
		endif;
     
		if($include_video_post=='addvideo'):
            $yt_video_content ='<br><iframe src="'.esc_url('https://www.youtube.com/embed/'.esc_attr($video_id)).'" title="'.esc_html($title).'" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>';
			$content .= $yt_video_content;
		endif;

	    $post_id = wp_insert_post(
				array(
					'comment_status' => 'closed',
					'ping_status' => 'closed',
					'post_author' => $author_id,
					'post_title' => $title,
					'post_content' => $content,
					'post_status' => $status,
					'post_type' => 'post',
					'post_date_gmt' => gmdate('Y-m-d H:i:s', strtotime($date)),
					'post_date' => $date,
					'edit_date' => 'true'
				));
    if($tags){
	  wp_set_post_tags($post_id, $tags, false);
	}
    if($categories){
	  $cat_arr = explode(',', $categories);
	  wp_set_post_categories($post_id, $cat_arr, false);
	}
	if($include_thumbnail == 'addthumbnail'):
		if(!empty($thumb_image_url)):
          $this->ytautocaptioncrafter_generate_featured_image($thumb_image_url, $post_id);
		endif;
	endif;
    if($post_id):
	   echo json_encode(array('status'=>'success','msg'=> esc_html__('Post Created Successfully','yt-autocaptioncrafter')));
	else:
	   echo json_encode(array('status'=>'fail','msg'=> esc_html__('Something went wrong','yt-autocaptioncrafter')));
	endif;
	wp_die();	
	}
    /**
	 * Yt Auto Caption Crafter Generate Featured Image
	 */ 
	public function ytautocaptioncrafter_generate_featured_image($image_url, $post_id){
        $upload_dir = wp_upload_dir();
        $image_data = file_get_contents($image_url);
        $filename = basename($image_url);
        if(wp_mkdir_p($upload_dir['path']))
            $file = $upload_dir['path'] . '/' . $post_id . '_' . $filename;
        else
            $file = $upload_dir['basedir'] . '/' . $post_id . '_' . $filename;
        file_put_contents($file, $image_data);
        $wp_filetype = wp_check_filetype($filename, null);
        $attachment = array(
            'post_mime_type' => $wp_filetype['type'],
            'post_title' => sanitize_file_name($filename),
            'post_content' => '',
            'post_status' => 'inherit'
        );
        $attach_id = wp_insert_attachment($attachment, $file, $post_id);
        require_once(ABSPATH . 'wp-admin/includes/image.php');
        $attach_data = wp_generate_attachment_metadata($attach_id, $file);
        $res1 = wp_update_attachment_metadata($attach_id, $attach_data);
        $res2 = set_post_thumbnail($post_id, $attach_id);
    }
	/**
	 * Yt Auto Caption Crafter General Api Settings Save
	 */
	public function ytautocaptioncrafter_general_api_settings(){
		extract($_POST);
		if(update_option('gptsniper_general_api', json_encode($_POST))){
			echo json_encode(array('status'=>true,'message'=>esc_html__("Saved Successfully","yt-autocaptioncrafter")));
		}else{
			echo json_encode(array('status'=>false,'message'=>esc_html__("Something went to wrong!","yt-autocaptioncrafter")));
		} 
	    wp_die();	
	}
	/**
	 * Post and Custom Post Meta Box Content Add Setting
	 */
	function ytautocaptioncrafter_add_custom_box() {
		$general_api = json_decode(get_option('gptsniper_general_api'),true);
		$screens = array();
		if(!empty($general_api['post_list_data'])){
			$screens = explode(",",$general_api['post_list_data']);
		}
		foreach ($screens as $screen ) {
			add_meta_box(
				'gptsniper_box_id',                 
				'GPT Sniper AI',      
				array( $this, 'ytautocaptioncrafter_custom_box_html'),  
				$screens                           
			);
		}
	}
	// Meta option Html View
	function ytautocaptioncrafter_custom_box_html($post) {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/ytautocaptioncrafter-gpt-meta-box.php';
	}
	function ytautocaptioncrafter_save_postdata($post_id) {

    }
		
	 /**
	 * Chat Gpt Content Generator
	 */  
    public function ytautocaptioncrafter_content_generator(){
        $general_api = json_decode(get_option('gptsniper_general_api'),true);
	    $openai_api_save = '';
        $user_key = '';
		if(!empty($general_api['api_key'])):
			$openai_api_save = $general_api['api_key'];
			$user_key ='yes';
		else:
			$user_key ='no';
			$openai_api_save = get_option('gpt_open_rendom_api_keys');
		endif;
		$getMaxTokens = 1000;
		if(!empty($general_api['max_tokens'])):
			$getMaxTokens = $general_api['max_tokens'];
		endif; 
		$getTemperature =0.5;
		if(!empty($general_api['temperature'])):
			$getTemperature = $general_api['temperature'];
		endif;
		$model_option = 'text-davinci-003';
		if(!empty($general_api['model_option'])):
			$model_option = $general_api['model_option'];
		endif;
		$presence_penalty = 0.01;
		if(!empty($general_api['presence_penalty'])): 
			$presence_penalty = $general_api['presence_penalty'];
	    endif;
		$frequency_penalty = 0.01;
		if(!empty($general_api['frequency_penalty'])): 
			$frequency_penalty = $general_api['frequency_penalty'];
	    endif;
		$best_of = 1;
		if(!empty($general_api['best_of'])): 
			$best_of = $general_api['best_of'];
	    endif;
		$top_p = 0.01;
		if(!empty($general_api['top_p'])): 
			$top_p = $general_api['top_p'];
	    endif;
		$TEXT = '';
		if(!empty($_POST['title'])):
		  $TEXT = sanitize_text_field($_POST['title']);
		endif;
		$language = 'english';
		if(!empty($_POST['openai_language'])):
		  $language = sanitize_text_field($_POST['openai_language']);
		endif;
        $media_image_url = '';
		$add_image = '';
		if(!empty($_POST['add_image'])):
		  $add_image = sanitize_text_field($_POST['add_image']);
		endif;
		$feature_image = '';
		if(!empty($_POST['feature_image'])):
		  $feature_image = sanitize_text_field($_POST['feature_image']);
		endif;
		$nopara = '3';
		if(!empty($_POST['number_of_paragraphs'])):
		  $nopara = sanitize_text_field($_POST['number_of_paragraphs']);
		endif;

		if($add_image==='true' || $feature_image==='true'){
			/**
			 * Image Code
			 */
			$ogj = str_replace(" ","%20",$TEXT);
			if(!empty($_POST['feature_image_size'])){
				$size = sanitize_text_field($_POST['feature_image_size']);
			}else{
				$size = "1024x1024";
			}
			if(!empty($ogj)){
				$args = array(
					"prompt" => "$language:$ogj",
					"n"=>1,
					"size"=>$size
				);  
			$data_string = json_encode($args);  
			$ch = curl_init('https://api.openai.com/v1/images/generations');
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");                                       
			curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                         
			curl_setopt($ch, CURLOPT_HTTPHEADER, array(
			'Authorization: Bearer '.$openai_api_save,
			'Content-Type: application/json'
			));
			$result = curl_exec($ch);
			$a = json_decode($result,true);
			if(isset($a['data'])){
				foreach($a['data'] as $a_child){
					$img = 'openai_images.png'; 
					$imgUrl = $a_child['url'];
					file_put_contents($img, file_get_contents($imgUrl));
					$img_url= get_home_url().'/wp-admin/openai_images.png';
					$new_image = sanitize_url($img_url);
					$res = $this->ytautocaptioncrafter_set_image_from_url($new_image);
                    if($res > 0):
						$media_image_url = wp_get_attachment_url($res);
						/**
						 * Set Feture Image Option
						 */
						if($feature_image=='true'):
						   $this->ytautocaptioncrafter_setfeature_images_byurl($_POST['post_id'],$media_image_url);
						endif;
                    endif;
				}
			  }
			} 

	    }
       
		/**
		 * Content Code
		 */
		 $large_content = '';
		 $prompt_text_heading = 'informative'.' heading(s) about ';
		 $formatted_prompt = 'write ' . strval( $nopara ) . ' ' . $prompt_text_heading . ' ' . $TEXT . ' in ' . $language . ' language seperated by <momoseperator>';
		 $heading_list = $this->ytautocaptioncrafter_create_heading_lists($formatted_prompt);
		 
		 if(!empty($heading_list['content']) && $heading_list['status'] == 200):
		     $large_content = $this->ytautocaptioncrafter_create_large_content($heading_list['content'],$language);
		 endif;  
		 $postContent = '';
		 $post_edit_url = admin_url().'post.php?post='.$_POST['post_id'].'&action=edit';
		 if($heading_list['status'] == 200){
           $postContent = $large_content['content']; 
		    if($add_image==='true'):
			   $with_image = '<img src="'.esc_url($imgUrl).'" alt='.esc_attr($TEXT).'><br>';
               $postContent = $with_image.' '.$postContent;
			endif;
			$result_data = array('status'=>$heading_list['status'],
		                         'content_data'=> $postContent,
								 'post_url' => $post_edit_url,
				                 'message' => esc_html__('Successfully',"yt-autocaptioncrafter")
				                 
		                        );
		   update_post_meta($_POST['post_id'], 'gpt_post_content', $postContent );

        }else{
			
			$result_data = array('status'=>$heading_list['status'],
		                         'content_data'=>$postContent,
								 'user_key'=>$user_key,
				                 'message' => esc_html__("Something went to wrong!","yt-autocaptioncrafter")
		                        );
		               
		}
		echo json_encode($result_data);
	wp_die(); 
    
	}
	
	/**
	 * Chat GPT Create Heading List
	 */ 
	public function ytautocaptioncrafter_create_heading_lists($formatted_prompt=false){
	    
	    $general_api = json_decode(get_option('gptsniper_general_api'),true);
        $openai_api_save = '';
		$user_key = '';
		if(!empty($general_api['api_key'])):
			$openai_api_save = $general_api['api_key'];
			$user_key ='yes';
		else:
			$user_key ='no';
			$openai_api_save = get_option('gpt_open_rendom_api_keys');
		endif;
	    $method = esc_html__('POST','yt-autocaptioncrafter');
	    $timeout = 45;
	    $url  = esc_url('https://api.openai.com/v1/completions');
	    $body = array(
            	'model' => 'text-davinci-003',
            	'prompt' => $formatted_prompt,
            	'temperature' => 0.7,
            	'max_tokens' => (int) 400,
            	'top_p' => 1,
            	'frequency_penalty' => 0.0,
            	'presence_penalty' => 0.0,
               );
        $args = array(
                'headers' => array(
                    'Content-Type'  => 'application/json',
                    'Authorization' => 'Bearer ' . $openai_api_save,
                   ),
                'method'  => $method,
                'timeout' => $timeout,
        		);
        if (!empty($body)) {
        	$args['body'] = wp_json_encode( $body );
        }	
        $response = wp_remote_post($url, $args); 
        $json = wp_remote_retrieve_body( $response );
        $headings_text ='';
        $details  = json_decode($json,true);
        $response = array(
            'status'  => $response['response']['code'],
            'message' => $response['response']['message'],
            'code'    => $response['response']['code'],
            'body'    => json_decode( $response['body'] ),
        );
        $headings = array();
        if (is_wp_error($response)) {
            return $headings;
        }
        $content = '';
        $message = '';
        $headinglist = '';
        if (isset($response['status']) && 200 === $response['status']) {
            $choices = isset($response['body']->choices ) ? $response['body']->choices : array();
            if (!empty($choices)) {
                foreach($choices as $choice) {
                  $content = $choice->text;
                }
            } else {
                $message .= esc_html__( 'Not enough choices generated.', 'yt-autocaptioncrafter' );
            }
            if (is_string($content)) {
                $content = preg_replace('/[0-9]+\./', '', $content);
        	    $headinglist  = explode( '<momoseperator>', $content );
            } 
        	return array(
        			'message' => $response['message'],
        			'status'  => $response['status'],
        			'content' => $headinglist,
        		   );
        }else{
           return array(
        			'message' => $message,
        			'status'  => $response['status'],
        			'content' => $headinglist,
        		   ); 
        }
	    
	}
	/**
	 * Chat GPT Create Large Content  
	 */ 
	public function ytautocaptioncrafter_create_large_content($headings=false,$language=false){
		$general_api = json_decode(get_option('gptsniper_general_api'),true);
		$openai_api_save = '';
		$user_key = '';
		if(!empty($general_api['api_key'])):
			$openai_api_save = $general_api['api_key'];
			$user_key ='yes';
		else:
			$user_key ='no';
			$openai_api_save = get_option('gpt_open_rendom_api_keys');
		endif;
		$method = esc_html__('POST','yt-autocaptioncrafter');
		$timeout = 45;
		$message = $content = '';
		//$language = esc_html__('english','yt-autocaptioncrafter');
		$prompt_text_article = esc_html__('article about','yt-autocaptioncrafter');
		$url = esc_url('https://api.openai.com/v1/completions');
		$getMaxTokens = 1000;
		if(!empty($general_api['max_tokens'])):
			$getMaxTokens = $general_api['max_tokens'];
		endif; 
		$getTemperature =0.7;
		if(!empty($general_api['temperature'])):
			$getTemperature = $general_api['temperature'];
		endif;
		$model_option = 'text-davinci-003';
		if(!empty($general_api['model_option'])):
			$model_option = $general_api['model_option'];
		endif;
		$presence_penalty = 0.01;
		if(!empty($general_api['presence_penalty'])): 
			$presence_penalty = $general_api['presence_penalty'];
		endif;
		$frequency_penalty = 0.01;
		if(!empty($general_api['frequency_penalty'])): 
			$frequency_penalty = $general_api['frequency_penalty'];
		endif;
		$best_of = 1;
		if(!empty($general_api['best_of'])): 
			$best_of = $general_api['best_of'];
		endif;
		$top_p = 1;
		if(!empty($general_api['top_p'])): 
			$top_p = $general_api['top_p'];
		endif;
		if($headings):
		  foreach ($headings as $index => $heading ) {
			$formatted_prompt  = 'One long paragraph on ' . $prompt_text_article . ' ' . $heading . ' without introduction and conclusion in ' . $language . ' language';
			$body = array(
				'model' => $model_option,
				'prompt' => $formatted_prompt,
				'temperature' =>(float)$getTemperature,
				'max_tokens' => (int)$getMaxTokens,
				'top_p' => (float)$top_p,
				'frequency_penalty' => (float)$frequency_penalty,
				'presence_penalty' => (float)$presence_penalty,
			   );
			$args = array(
					'headers' => array(
						'Content-Type'  => 'application/json',
						'Authorization' => 'Bearer ' . $openai_api_save,
					),
					'method'  => $method,
					'timeout' => $timeout,
					);
			if (!empty($body)) {
				$args['body'] = wp_json_encode( $body );
			}	
			$response = wp_remote_post($url, $args); 
			$json = wp_remote_retrieve_body( $response );
			$details  = json_decode($json,true);
			$response = array(
				'status'  => $response['response']['code'],
				'message' => $response['response']['message'],
				'code'    => $response['response']['code'],
				'body'    => json_decode( $response['body'] ),
			   );
			if(is_wp_error($response)) {
				$message = esc_html__( 'Something went wrong with provided output from server.', 'yt-autocaptioncrafter');
			}
			if(isset( $response['status'] ) && 200 === $response['status'] ) {
				$message .= isset( $response['body']->error->message ) ? $response['body']->error->message : esc_html__( 'Provided url not found.', 'yt-autocaptioncrafter');
			}
			if (isset($response['status'] ) && 200 === $response['status'] ) {
				$choices = isset( $response['body']->choices ) ? $response['body']->choices : array();
				if (!empty($choices)) {
					foreach ( $choices as $choice ) {
					  $content .= $choice->text;
					}
				} else {
					 $message .= esc_html__( 'Not enough choices generated.', 'yt-autocaptioncrafter');
				}
			}
		}
		endif;
		return array(
		'message' => $message,
		'status'  => $response['status'],
		'content' => $content,
		); 
	     
	}
	
	/**
	 * Chat Gpt Sniper Images Generator 
	 */
	public function ytautocaptioncrafter_openai_img_generator() {
		$general_api = json_decode(get_option('gptsniper_general_api'),true);
        $user_key = '';
		if(!empty($general_api['api_key'])):
			$openai_api_save = $general_api['api_key'];
			$user_key ='yes';
		else:
			$user_key ='no';
			$openai_api_save = get_option('gpt_open_rendom_api_keys');
		endif;
		$data_keys = '';
		if(!empty($_POST['data_keys'])):
			$data_keys = sanitize_text_field($_POST['data_keys']);
		endif;
		$image_artist = '';
		if(!empty($_POST['image_artist'])):
			$image_artist = sanitize_text_field($_POST['image_artist']);
		endif;
		$image_style = '';
		if(!empty($_POST['image_style'])):
			$image_style = sanitize_text_field($_POST['image_style']);
		endif;
		$image_photography = '';
		if(!empty($_POST['image_photography'])):
			$image_photography = sanitize_text_field($_POST['image_photography']);
		endif;
		$image_lighting = '';
		if(!empty($_POST['image_lighting'])):
			$image_lighting = sanitize_text_field($_POST['image_lighting']);
		endif;
		$image_subject = '';
		if(!empty($_POST['image_subject'])):
			$image_subject = sanitize_text_field($_POST['image_subject']);
		endif;
		$image_Camera = '';
		if(!empty($_POST['image_Camera'])):
			$image_Camera = sanitize_text_field($_POST['image_Camera']);
		endif;
		$image_composition = '';
		if(!empty($_POST['image_composition'])):
			$image_composition = sanitize_text_field($_POST['image_composition']);
		endif;
		$images_resolution = '';
		if(!empty($_POST['images_resolution'])):
			$images_resolution = sanitize_text_field($_POST['images_resolution']);
		endif;
		$image_color = '';
		if(!empty($_POST['image_color'])):
			$image_color = sanitize_text_field($_POST['image_color']);
		endif;
		$image_effects = '';
		if(!empty($_POST['image_effects'])):
			$image_effects = sanitize_text_field($_POST['image_effects']);
		endif;
		$image_number_of = '';
		if(!empty($_POST['image_number_of'])):
			$image_number_of = sanitize_text_field($_POST['image_number_of']);
		else:
			$image_number_of = 1;
		endif;
		$data_keys = "$data_keys,$image_artist,$image_photography,$image_lighting,$image_subject,$image_Camera,$image_composition,$images_resolution,$image_color,$image_effects";
		$ogj = str_replace(" ","%20",$data_keys);
		
        if(!empty($_POST['image_size'])){
			$size = sanitize_text_field($_POST['image_size']);
		}else{
			$size = "1024x1024";
		}
		
		ob_start();
		if(!empty($ogj)){
			$args = array(
				"prompt" => $ogj,
				"n"=>(int)$image_number_of,
				"size"=>$size
			);    
		$data_string = json_encode($args);  
		$ch = curl_init('https://api.openai.com/v1/images/generations');
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");                                       
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data_string);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);                         
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(
		'Authorization: Bearer '.$openai_api_save,
		'Content-Type: application/json'
		));
			$result = curl_exec($ch);
			// Get Status
			$httpcode = curl_getinfo($ch, CURLINFO_RESPONSE_CODE);
			$a = json_decode($result,true);  
			if(isset($a['data'])){
				$ij = 1;
				foreach($a['data'] as $a_child){
					$ij = rand();
					$imgUrl = $a_child['url'];
					$img = 'openai_images_'.$ij.'.png'; 
					file_put_contents($img, file_get_contents($imgUrl));
					$img_url= get_home_url().'/wp-admin/openai_images_'.$ij.'.png';
					echo '<div class="gpt-openai-images">
							<img src="'.esc_url($img_url).'" alt="'.esc_attr__('Openai','yt-autocaptioncrafter').'">
								<div class="gpt-action">
								<a href="javascript:void(0)" data-url="'.esc_url($img_url).'" class="gpt-btn gpt-savemedia-image gpt_download_image" download>'.esc_html__('Download','yt-autocaptioncrafter').'</a> 
								<a href="'.esc_url($img_url).'" target="_blank" class="gpt-btn">'.esc_html__('View','yt-autocaptioncrafter').'</a> 
							</div> 
						</div>';   
				}
			}else{
				echo '<p>'.esc_html($a['error']['message']).'</p>';
				
			} 	
		}else{
			echo '<p>'.esc_html($a['error']['message']).'</p>';
		}
		wp_die();
	}
	
	/**
	 * WP Media Libary In Image File Save
	 */
	public function ytautocaptioncrafter_set_image_from_url($url) {
		$tmp = download_url($url);
		$file_array = array(
			'name' => basename( $url ),
			'tmp_name' => $tmp
		);
		if(is_wp_error($tmp)){
			@unlink( $file_array[ 'tmp_name' ] );
			return $tmp;
		}
		$post_id = '0';
		$id = media_handle_sideload( $file_array, $post_id );
		if(is_wp_error($id)){
			@unlink( $file_array['tmp_name']);
			return $id;
		}
		return $id;
	}
	/**
	 * Gpt Sniper Set Feature Image by Url
	 */ 
	public function ytautocaptioncrafter_setfeature_images_byurl($post_id=false,$image_url=false){
        $image_name  = 'openai_images.png';
		$upload_dir  = wp_upload_dir(); // Set upload folder
		$image_data  = file_get_contents($image_url); // Get image data
		$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
		$filename  = basename( $unique_file_name ); // Create image file name
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}
		// Create the image  file on the server
		file_put_contents( $file, $image_data );
		$wp_filetype = wp_check_filetype( $filename, null );
		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'     => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'    => 'inherit'
		);
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );
		require_once(ABSPATH . 'wp-admin/includes/image.php');
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );
		wp_update_attachment_metadata( $attach_id, $attach_data );
		set_post_thumbnail($post_id, $attach_id);
    }
	/**
	 * generate article using RSS URL
	 */
	 public function ytautocaptioncrafter_submit(){	 	
		 if ( !empty( $_POST['rssurl_menual_submit'] ) ) {
			 $dfyblogs_hyperlink = '';
			 if(!empty($_POST['dfyblogs_hyperlink'])){
				$dfyblogs_hyperlink = $_POST['dfyblogs_hyperlink'];
			 }
			 $data['dfyblogs_rssurl'] = isset( $_POST['dfyblogs_rssurl'] ) ?  sanitize_textarea_field( $_POST['dfyblogs_rssurl'] ): array();
			 $feed = '';
			 if(!empty($_POST['dfyblogs_rssurl'])){
				$feed = $_POST['dfyblogs_rssurl'];
			 }
			 $cat = '';
			 if(!empty($_POST['cat'])){
				$cat = $_POST['cat'];
			 }
			 if(!empty($_POST['dfyblogs_rssurl'])){
				 $image_data = '';
				 $feed = $_POST['dfyblogs_rssurl'];
				 $xml= @simplexml_load_file($feed);
				 
				if (!empty($xml)) {
				$rss = simplexml_load_file($feed, 'SimpleXMLElement', LIBXML_NOWARNING);
					 $namespaces = $rss->getNamespaces(true);
					 
					 //image from content:encode
					 $xml = file_get_contents($feed);
					 $xml = str_replace('<content:encoded>', '<content_encoded>', $xml);
					 $xml = str_replace('</content:encoded>', '</content_encoded>', $xml);
					 $obj = SimpleXML_Load_String($xml, 'SimpleXMLElement', LIBXML_NOCDATA);
					$feed = [];
					// A REGEX THAT FINDS IMAGE TAGS SRC ATTRIBUTE
					$rgx
					= '~'                  // REGEX DELIMITER
					. 'src="'              // SRC INSIDE IMAGE TAG
					. '('                  // START CAPTURE GROUP
					. '[^"]*'              // ANYTHING UP TO END
					. ')'                  // ENDOF CAPTURE GROUP
					. '"'                  // END OF SRC ATTRIBUTE
					. '~'                  // REGEX DELIMITER
					. 'i'                  // FLAG: CASE INSENSITIVE
					. 's'                  // FLAG: SINGLE LINE
					;

					foreach ($obj->channel->item as $item)
					{
						$content       = $item->content_encoded;
						preg_match_all($rgx, $content, $match);
						if(!empty($match[0][0])){
						$node['image'] = $match[0][0];
						$feed[] = $node;
						}
					}
						
					 $count = 0;
					 foreach ($rss->channel->item as $item) {
						 
						$imageAlt = '';
						if(!empty($namespaces['media'])){
							$media_content = $item->children($namespaces['media']);
							foreach($media_content as $i){
								$imageAlt = (string)$i->attributes()->url;
							}
						}
						$desimg = preg_match_all('/(<img .*?>)/', $item->description, $img_tag);
						if($desimg != '0'){
							$image = $img_tag;
							$doc = new DOMDocument();
							$doc->loadHTML($img_tag['0']['0']);
							$xpath = new DOMXPath($doc);
							$src = $xpath->evaluate("string(//img/@src)"); # "/images/image.jpg"
							$imageAlt = $src;
							
						}
						if(empty($imageAlt)){
							$imageAlt = '';
							if(!empty($feed[$count])){
							$imageAlt = $feed[$count];
							$imageAlt = $imageAlt['image'];
							$imageAlt = str_replace('src="', '',$imageAlt);
							$imageAlt = str_replace('"', '',$imageAlt);
							}
							
						}
						$title       = html_entity_decode($item->title);
						$description = html_entity_decode($item->description);
						$pubDate     = html_entity_decode($item->pubDate);
						$image       = html_entity_decode($item->image);
						$link        = html_entity_decode( $item->link );
						$imageAlt    = html_entity_decode($imageAlt);
						$user_id     = get_current_user_id();
						$enclosure   = html_entity_decode($item->enclosure['url']);
						
						if(empty($imageAlt)){
							$imageAlt    = html_entity_decode($item->image);
						}
						if(empty($imageAlt)){
							$imageAlt    = $enclosure;
						}
						//upload image in media library
						if(!empty($imageAlt)){
							$upload_dir = wp_upload_dir();
							$image_data = file_get_contents( $imageAlt );
							if($image_data == 0){
								echo "";
							}else{
								if(!empty($image_data)){
									$filename = rand().'.png'; 
									if ( wp_mkdir_p( $upload_dir['path'] ) ) {
									   $file = $upload_dir['path'] . '/' . $filename;
									}
									else {
									   $file = $upload_dir['basedir'] . '/' . $filename;
									}
									file_put_contents( $file, $image_data );
									$wp_filetype = wp_check_filetype( $filename, null );

									$attachment = array(
									  'post_mime_type' => $wp_filetype['type'],
									  'post_title' => sanitize_file_name( $filename ),
									  'post_content' => '',
									  'post_status' => 'inherit'
									);

									$attach_id = wp_insert_attachment( $attachment, $file );
									require_once( ABSPATH . 'wp-admin/includes/image.php' );
									$attach_data = wp_generate_attachment_metadata( $attach_id, $file );
									wp_update_attachment_metadata( $attach_id, $attach_data );
								}
							}
						}
						//Create hyperlink
						if(!empty($dfyblogs_hyperlink)){
							$descarr = explode(' ', $description);
							shuffle($descarr);
							if(!empty($descarr[0])){
								$hyperlink0 = '<a href="'.esc_url($dfyblogs_hyperlink).'">'.$descarr[0].'</a>';
								$description = str_replace($descarr[0],$hyperlink0,$description);
							}
							if(!empty($descarr[1])){
								$hyperlink1 = '<a href="'.esc_url($dfyblogs_hyperlink).'">'.$descarr[1].'</a>';
								$description = str_replace($descarr[1],$hyperlink1,$description);
							}
						}
						//Update data into post
						if(!empty($cat)){
							$my_post = array(
								'post_title'    => $title,
								'post_content'  => $description,
								'post_status'   => 'publish',
								'post_type'     => 'post',
								'post_author'   => $user_id,
								'post_category' => $cat,
							);
						}
						else{
							$my_post = array(
								'post_title'    => $title,
								'post_content'  => $description,
								'post_status'   => 'publish',
								'post_type'     => 'post',
								'post_author'   => $user_id,
							);
						}
						
						$post_id = wp_insert_post( $my_post ); 
						if(!empty($attach_id)){
							set_post_thumbnail($post_id, $attach_id);
						}
						update_post_meta( $post_id, 'post_link', $link );
						if(!empty($imageAlt)){
							update_post_meta( $post_id, 'post_imgalt', $imageAlt );
						}
						update_post_meta( $post_id, 'post_date', $pubDate );
						$count++;
						if($count==20) break;
					}
					if(!empty($post_id)){
						add_action( 'admin_notices', array($this, 'ytautocaptioncrafter_admindata__success') );
					}
					else{
						add_action( 'admin_notices', array($this, 'vrs_admindata__fail') );
					}
					$scheduledata = get_option('dfyblogs_schedule_data');
    				 if(empty($scheduledata)){
    					update_option( 'dfyblogs_schedule_data', $data, 'yes' );
    				 }else{
    					 array_push($scheduledata,$data['dfyblogs_rssurl']);
    					 update_option( 'dfyblogs_schedule_data', $scheduledata, 'yes' );
    					 
    				 }
				 }
				 else{
				      add_action( 'admin_notices', array($this, 'auth_wrongurl__fail') );
				 }
				 
			 }
			 else{
				add_action( 'admin_notices', array($this, 'vrs_admindata__fail') );
			 }
		 }
	 }
	 public function ytautocaptioncrafter_admindata__success(){
		echo '<div class="notice notice-success is-dismissible">
				<p>'.esc_html__( 'Articles have been generated successfully.', 'yt-autocaptioncrafter' ).'<a href="'.get_home_url().'/wp-admin/edit.php" target="_blank">'.esc_html__( 'Click here to view the generated articles.', 'yt-autocaptioncrafter' ).'</a></p>
			</div>';
	}
	public function vrs_admindata__fail(){
		echo '<div class="notice notice-error is-dismissible">
				<p>'.esc_html__( 'Something went wrong.', 'dfyblogs' ).'</p>
			</div>';
	}
}	